==> broadleaf-open-admin-platform-1.5.4-20120324.000219-12-sources.jar: org/broadleafcommerce/openadmin/audit/AdminAuditableListener.java <==
/*
 * Copyright 2008-2009 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.broadleafcommerce.openadmin.audit;

import org.broadleafcommerce.openadmin.server.service.SandBoxContext;
import org.broadleafcommerce.openadmin.time.SystemTime;

import javax.persistence.Embedded;
import javax.persistence.Entity;
import javax.persistence.PrePersist;
import javax.persistence.PreUpdate;
import java.lang.reflect.Field;
import java.util.Calendar;

public class AdminAuditableListener {

    @PrePersist
    public void setAuditCreatedBy(Object entity) throws Exception {
        if (entity.getClass().isAnnotationPresent(Entity.class)) {
            Field field = getSingleField(entity.getClass(), "auditable");
            field.setAccessible(true);
            if (field.isAnnotationPresent(Embedded.class)) {
            	Object auditable = field.get(entity);
            	if (auditable == null) {
            		field.set(entity, new AdminAuditable());
            		auditable = field.get(entity);
            	}
        		Field temporalField = auditable.getClass().getDeclaredField("dateCreated");
        		Field agentField = auditable.getClass().getDeclaredField("createdBy");
        		setAuditValueTemporal(temporalField, auditable);
        		setAuditValueAgent(agentField, auditable);
            }
        }
    }

    @PreUpdate
    public void setAuditUpdatedBy(Object entity) throws Exception {
        if (entity.getClass().isAnnotationPresent(Entity.class)) {
            Field field = getSingleField(entity.getClass(), "auditable");
            field.setAccessible(true);
            if (field.isAnnotationPresent(Embedded.class)) {
            	Object auditable = field.get(entity);
            	if (auditable == null) {
            		field.set(entity, new AdminAuditable());
            		auditable = field.get(entity);
            	}
        		Field temporalField = auditable.getClass().getDeclaredField("dateUpdated");
        		Field agentField = auditable.getClass().getDeclaredField("updatedBy");
        		setAuditValueTemporal(temporalField, auditable);
        		setAuditValueAgent(agentField, auditable);
            }
        }
    }

    protected void setAuditValueTemporal(Field field, Object entity) throws IllegalArgumentException, IllegalAccessException {
    	Calendar cal = SystemTime.asCalendar();
    	field.setAccessible(true);
    	field.set(entity, cal.getTime());
    }

    protected void setAuditValueAgent(Field field, Object entity) throws IllegalArgumentException, IllegalAccessException {
    	try {
            SandBoxContext context = SandBoxContext.getSandBoxContext();
            if (context != null) {
                field.setAccessible(true);
                field.set(entity, context.getAdminUser());
            }
        } catch (IllegalStateException e) {
            //do nothing
		} catch (Exception e) {
			e.printStackTrace();
		}
    }

    private Field getSingleField(Class<?> clazz, String fieldName) throws IllegalStateException {
        try {
            return clazz.getDeclaredField(fieldName);
        } catch (NoSuchFieldException nsf) {
            // Try superclass
            if (clazz.getSuperclass() != null) {
                return getSingleField(clazz.getSuperclass(), fieldName);
            }

            return null;
        }
    }
}

==> broadleaf-open-admin-platform-1.6.2-20120831.000303-9-sources.jar: org/broadleafcommerce/openadmin/audit/AdminAuditableListener.java <==
/*
 * Copyright 2008-2009 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.broadleafcommerce.openadmin.audit;

import org.broadleafcommerce.openadmin.server.service.SandBoxContext;
import org.broadleafcommerce.common.time.SystemTime;

import javax.persistence.Embedded;
import javax.persistence.Entity;
import javax.persistence.PrePersist;
import javax.persistence.PreUpdate;
import java.lang.reflect.Field;
import java.util.Calendar;

public class AdminAuditableListener {

    @PrePersist
    public void setAuditCreatedBy(Object entity) throws Exception {
        if (entity.getClass().isAnnotationPresent(Entity.class)) {
            Field field = getSingleField(entity.getClass(), "auditable");
            field.setAccessible(true);
            if (field.isAnnotationPresent(Embedded.class)) {
            	Object auditable = field.get(entity);
            	if (auditable == null) {
            		field.set(entity, new AdminAuditable());
            		auditable = field.get(entity);
            	}
        		Field temporalField = auditable.getClass().getDeclaredField("dateCreated");
        		Field agentField = auditable.getClass().getDeclaredField("createdBy");
        		setAuditValueTemporal(temporalField, auditable);
        		setAuditValueAgent(agentField, auditable);
            }
        }
    }

    @PreUpdate
    public void setAuditUpdatedBy(Object entity) throws Exception {
        if (entity.getClass().isAnnotationPresent(Entity.class)) {
            Field field = getSingleField(entity.getClass(), "auditable");
            field.setAccessible(true);
            if (field.isAnnotationPresent(Embedded.class)) {
            	Object auditable = field.get(entity);
            	if (auditable == null) {
            		field.set(entity, new AdminAuditable());
            		auditable = field.get(entity);
            	}
        		Field temporalField = auditable.getClass().getDeclaredField("dateUpdated");
        		Field agentField = auditable.getClass().getDeclaredField("updatedBy");
        		setAuditValueTemporal(temporalField, auditable);
        		setAuditValueAgent(agentField, auditable);
            }
        }
    }

    protected void setAuditValueTemporal(Field field, Object entity) throws IllegalArgumentException, IllegalAccessException {
    	Calendar cal = SystemTime.asCalendar();
    	field.setAccessible(true);
    	field.set(entity, cal.getTime());
    }

    protected void setAuditValueAgent(Field field, Object entity) throws IllegalArgumentException, IllegalAccessException {
    	try {
            SandBoxContext context = SandBoxContext.getSandBoxContext();
            if (context != null) {
                field.setAccessible(true);
                field.set(entity, context.getAdminUser());
            }
        } catch (IllegalStateException e) {
            //do nothing
		} catch (Exception e) {
			e.printStackTrace();
		}
    }

    private Field getSingleField(Class<?> clazz, String fieldName) throws IllegalStateException {
        try {
            return clazz.getDeclaredField(fieldName);
        } catch (NoSuchFieldException nsf) {
            // Try superclass
            if (clazz.getSuperclass() != null) {
                return getSingleField(clazz.getSuperclass(), fieldName);
            }

            return null;
        }
    }
}
